@@ -1,11 +1,12 @@
 import pathlib
 from typing import IO, Hashable, Iterable, Mapping, Optional, Tuple, Union
 
+import pandas as pd
 import pint
 import xarray as xr
 from loguru import logger
 
-from . import _accessor_base
+from . import _accessor_base, pm2io
 from ._units import ureg
 
 
@@ -95,6 +96,67 @@ class DatasetDataFormatAccessor(_accessor_base.BaseDatasetAccessor):
         ensure_valid_data_variables(self._ds)
         ensure_valid_attributes(self._ds)
 
+    def to_interchange_format(self, time_format: str = "%Y") -> pd.DataFrame:
+        """Convert dataset to the interchange format.
+
+        The interchange format consists of a pandas DataFrame in wide format with the
+        meta data dictionary stored in the DataFrame's attrs dict.
+
+        Parameters
+        ----------
+        time_format: str, optional
+          string for strftime formatting of the "time" axis.
+
+        Returns
+        -------
+        df: pd.DataFrame
+        """
+        dsd = self._ds.pr.dequantify()
+        # additional coordinates are not yet supported, so drop them
+        dsd = dsd.reset_coords(drop=True)
+
+        dsd["time"] = dsd["time"].dt.strftime(time_format)
+
+        if "entity_terminology" in self._ds.attrs:
+            entity_col = f"entity ({self._ds.attrs['entity_terminology']})"
+        else:
+            entity_col = "entity"
+
+        dfs = []
+        for x in dsd:
+            df = (
+                dsd[x].to_dataset("time").to_dataframe().dropna(how="all").reset_index()
+            )
+            df[entity_col] = x
+            df["unit"] = dsd[x].attrs["units"]
+            dfs.append(df)
+
+        df = pd.concat(dfs, ignore_index=True)
+
+        df, dims = pm2io._data_reading.sort_columns_and_rows(
+            df,
+            dimensions=[dim for dim in dsd.dims if dim != "time"]
+            + [entity_col, "unit"],
+        )
+
+        dimensions = {}
+        all_dimensions = [str(dim) for dim in dsd.dims] + [entity_col, "unit"]
+        for entity in dsd:
+            dims = [str(dim) for dim in dsd[entity].dims] + [entity_col, "unit"]
+            if set(dims) == set(all_dimensions):
+                # use default option for entities which use all the dataset's dimensions
+                if "*" not in dimensions:
+                    dimensions["*"] = all_dimensions
+            else:
+                dimensions[entity] = dims
+
+        df.attrs = {
+            "attrs": self._ds.attrs,
+            "time_format": time_format,
+            "dimensions": dimensions,
+        }
+        return df
+
     def to_netcdf(
         self,
         path: Union[pathlib.Path, str],
@@ -159,6 +221,9 @@ def ensure_valid_coordinates(ds: xr.Dataset):
     additional_coords = set(ds.coords) - set(ds.dims)
     for coord in ds.coords:
         if not isinstance(coord, str):
+            # Note: can not be tested properly because xarray deals poorly with
+            # coordinate names which are not sortable with strings so the test never
+            # gets here anyway
             logger.error(
                 f"Coordinate {coord!r} is of type {type(coord)}, but "
                 f"only strings are allowed."
@@ -200,6 +265,7 @@ def ensure_valid_attributes(ds: xr.Dataset):
         "cat",
         "sec_cats",
         "scen",
+        "entity_terminology",
     }
     unknown_attr_keys = set(ds.attrs.keys()) - valid_attr_keys
     if unknown_attr_keys:
@@ -355,7 +421,8 @@ def ensure_valid_dimensions(ds: xr.Dataset):
             included_optional_dims.append(sec_cat)
             if sec_cat not in ds.dims:
                 logger.error(
-                    f"Secondary category {sec_cat!r} defined, but not found in dims."
+                    f"Secondary category {sec_cat!r} defined, but not found in dims: "
+                    f"{ds.dims}."
                 )
                 raise ValueError(f"Secondary category {sec_cat!r} not in dims")
 
