@@ -12,6 +12,7 @@ def test_metadata_properties(opulent_ds):
     assert ds.pr.history == (
         "2021-01-14 14:50 data invented\n" "2021-01-14 14:51 additional processing step"
     )
+    assert ds.pr.entity_terminology == "primap2"
 
     ds.pr.references = "references"
     assert ds.pr.references == "references"
@@ -27,3 +28,5 @@ def test_metadata_properties(opulent_ds):
     assert ds.pr.institution == "institution"
     ds.pr.history = "history"
     assert ds.pr.history == "history"
+    ds.pr.entity_terminology = "entity_terminology"
+    assert ds.pr.entity_terminology == "entity_terminology"
